@@ -3,10 +3,12 @@
 use crate::backup_progress::BackupProgress;
 use crate::backup_reason::Reason;
 use crate::chunk::{GenerationChunk, GenerationChunkError};
-use crate::chunker::{Chunker, ChunkerError};
+use crate::chunker::{ChunkerError, FileChunks};
 use crate::chunkid::ChunkId;
-use crate::client::{AsyncBackupClient, ClientError};
+use crate::client::{BackupClient, ClientError};
 use crate::config::ClientConfig;
+use crate::db::DatabaseError;
+use crate::dbgen::FileId;
 use crate::error::ObnamError;
 use crate::fsentry::{FilesystemEntry, FilesystemKind};
 use crate::fsiter::{AnnotatedFsEntry, FsIterError, FsIterator};
@@ -24,7 +26,7 @@ const SQLITE_CHUNK_SIZE: usize = MIB as usize;
 
 /// A running backup.
 pub struct BackupRun<'a> {
-    client: &'a AsyncBackupClient,
+    client: &'a BackupClient,
     policy: BackupPolicy,
     buffer_size: usize,
     progress: Option<BackupProgress>,
@@ -49,6 +51,10 @@ pub enum BackupError {
     #[error(transparent)]
     LocalGenerationError(#[from] LocalGenerationError),
 
+    /// An error using a Database.
+    #[error(transparent)]
+    Database(#[from] DatabaseError),
+
     /// An error splitting data into chunks.
     #[error(transparent)]
     ChunkerError(#[from] ChunkerError),
@@ -84,7 +90,7 @@ struct OneRootBackupOutcome {
 #[derive(Debug)]
 pub struct RootsBackupOutcome {
     /// The number of backed up files.
-    pub files_count: i64,
+    pub files_count: FileId,
     /// The errors encountered while backing up files.
     pub warnings: Vec<BackupError>,
     /// CACHEDIR.TAG files that aren't present in in a previous generation.
@@ -95,10 +101,7 @@ pub struct RootsBackupOutcome {
 
 impl<'a> BackupRun<'a> {
     /// Create a new run for an initial backup.
-    pub fn initial(
-        config: &ClientConfig,
-        client: &'a AsyncBackupClient,
-    ) -> Result<Self, BackupError> {
+    pub fn initial(config: &ClientConfig, client: &'a BackupClient) -> Result<Self, BackupError> {
         Ok(Self {
             client,
             policy: BackupPolicy::default(),
@@ -110,7 +113,7 @@ impl<'a> BackupRun<'a> {
     /// Create a new run for an incremental backup.
     pub fn incremental(
         config: &ClientConfig,
-        client: &'a AsyncBackupClient,
+        client: &'a BackupClient,
     ) -> Result<Self, BackupError> {
         Ok(Self {
             client,
@@ -129,7 +132,7 @@ impl<'a> BackupRun<'a> {
         match genid {
             None => {
                 // Create a new, empty generation.
-                NascentGeneration::create(oldname)?;
+                NascentGeneration::create(oldname)?.close()?;
 
                 // Open the newly created empty generation.
                 Ok(LocalGeneration::open(oldname)?)
@@ -193,7 +196,9 @@ impl<'a> BackupRun<'a> {
                     }
                 }
             }
-            new.file_count()
+            let count = new.file_count();
+            new.close()?;
+            count
         };
         self.finish();
         let gen_id = self.upload_nascent_generation(newpath).await?;
@@ -237,7 +242,8 @@ impl<'a> BackupRun<'a> {
                         Err(err) => {
                             warnings.push(err);
                         }
-                        Ok(o) => {
+                        Ok(None) => (),
+                        Ok(Some(o)) => {
                             if let Err(err) =
                                 new.insert(o.entry, &o.ids, o.reason, o.is_cachedir_tag)
                             {
@@ -260,16 +266,17 @@ impl<'a> BackupRun<'a> {
         &self,
         entry: AnnotatedFsEntry,
         old: &LocalGeneration,
-    ) -> Result<FsEntryBackupOutcome, BackupError> {
+    ) -> Result<Option<FsEntryBackupOutcome>, BackupError> {
         let path = &entry.inner.pathbuf();
         info!("backup: {}", path.display());
         self.found_live_file(path);
         let reason = self.policy.needs_backup(old, &entry.inner);
         match reason {
             Reason::IsNew | Reason::Changed | Reason::GenerationLookupError | Reason::Unknown => {
-                Ok(self.backup_one_entry(&entry, path, reason).await)
+                Ok(Some(self.backup_one_entry(&entry, path, reason).await))
             }
-            Reason::Unchanged | Reason::Skipped | Reason::FileError => {
+            Reason::Skipped => Ok(None),
+            Reason::Unchanged | Reason::FileError => {
                 let fileno = old.get_fileno(&entry.inner.pathbuf())?;
                 let ids = if let Some(fileno) = fileno {
                     let mut ids = vec![];
@@ -280,12 +287,12 @@ impl<'a> BackupRun<'a> {
                 } else {
                     vec![]
                 };
-                Ok(FsEntryBackupOutcome {
+                Ok(Some(FsEntryBackupOutcome {
                     entry: entry.inner,
                     ids,
                     reason,
                     is_cachedir_tag: entry.is_cachedir_tag,
-                })
+                }))
             }
         }
     }
@@ -361,7 +368,7 @@ impl<'a> BackupRun<'a> {
         let mut chunk_ids = vec![];
         let file = std::fs::File::open(filename)
             .map_err(|err| ClientError::FileOpen(filename.to_path_buf(), err))?;
-        let chunker = Chunker::new(size, file, filename);
+        let chunker = FileChunks::new(size, file, filename);
         for item in chunker {
             let chunk = item?;
             if let Some(chunk_id) = self.client.has_chunk(chunk.meta()).await? {
