@@ -1,15 +1,16 @@
 //! The `backup` subcommand.
 
 use crate::backup_run::BackupRun;
-use crate::client::AsyncBackupClient;
+use crate::client::BackupClient;
 use crate::config::ClientConfig;
+use crate::dbgen::FileId;
 use crate::error::ObnamError;
 use crate::generation::GenId;
 
 use log::info;
 use std::time::SystemTime;
 use structopt::StructOpt;
-use tempfile::NamedTempFile;
+use tempfile::tempdir;
 use tokio::runtime::Runtime;
 
 /// Make a backup.
@@ -26,24 +27,25 @@ impl Backup {
     async fn run_async(&self, config: &ClientConfig) -> Result<(), ObnamError> {
         let runtime = SystemTime::now();
 
-        let client = AsyncBackupClient::new(config)?;
+        let client = BackupClient::new(config)?;
         let genlist = client.list_generations().await?;
 
-        let oldtemp = NamedTempFile::new()?;
-        let newtemp = NamedTempFile::new()?;
+        let temp = tempdir()?;
+        let oldtemp = temp.path().join("old.db");
+        let newtemp = temp.path().join("new.db");
 
         let (is_incremental, outcome) = match genlist.resolve("latest") {
             Err(_) => {
                 info!("fresh backup without a previous generation");
                 let mut run = BackupRun::initial(config, &client)?;
-                let old = run.start(None, oldtemp.path()).await?;
-                (false, run.backup_roots(config, &old, newtemp.path()).await?)
+                let old = run.start(None, &oldtemp).await?;
+                (false, run.backup_roots(config, &old, &newtemp).await?)
             }
             Ok(old_id) => {
                 info!("incremental backup based on {}", old_id);
                 let mut run = BackupRun::incremental(config, &client)?;
-                let old = run.start(Some(&old_id), oldtemp.path()).await?;
-                (true, run.backup_roots(config, &old, newtemp.path()).await?)
+                let old = run.start(Some(&old_id), &oldtemp).await?;
+                (true, run.backup_roots(config, &old, &newtemp).await?)
             }
         };
 
@@ -76,7 +78,7 @@ impl Backup {
 
 fn report_stats(
     runtime: &SystemTime,
-    file_count: i64,
+    file_count: FileId,
     gen_id: &GenId,
     num_warnings: usize,
 ) -> Result<(), ObnamError> {
