@@ -1,6 +1,6 @@
 //! The `gen-info` subcommand.
 
-use crate::client::AsyncBackupClient;
+use crate::client::BackupClient;
 use crate::config::ClientConfig;
 use crate::error::ObnamError;
 use log::info;
@@ -26,7 +26,7 @@ impl GenInfo {
     async fn run_async(&self, config: &ClientConfig) -> Result<(), ObnamError> {
         let temp = NamedTempFile::new()?;
 
-        let client = AsyncBackupClient::new(config)?;
+        let client = BackupClient::new(config)?;
 
         let genlist = client.list_generations().await?;
         let gen_id = genlist.resolve(&self.gen_ref)?;
