@@ -1,7 +1,7 @@
 //! The `get-chunk` subcommand.
 
 use crate::chunkid::ChunkId;
-use crate::client::AsyncBackupClient;
+use crate::client::BackupClient;
 use crate::config::ClientConfig;
 use crate::error::ObnamError;
 use std::io::{stdout, Write};
@@ -24,7 +24,7 @@ impl GetChunk {
     }
 
     async fn run_async(&self, config: &ClientConfig) -> Result<(), ObnamError> {
-        let client = AsyncBackupClient::new(config)?;
+        let client = BackupClient::new(config)?;
         let chunk_id: ChunkId = self.chunk_id.parse().unwrap();
         let chunk = client.fetch_chunk(&chunk_id).await?;
         let stdout = stdout();
