@@ -1,8 +1,10 @@
 //! The `restore` subcommand.
 
 use crate::backup_reason::Reason;
-use crate::client::{AsyncBackupClient, ClientError};
+use crate::client::{BackupClient, ClientError};
 use crate::config::ClientConfig;
+use crate::db::DatabaseError;
+use crate::dbgen::FileId;
 use crate::error::ObnamError;
 use crate::fsentry::{FilesystemEntry, FilesystemKind};
 use crate::generation::{LocalGeneration, LocalGenerationError};
@@ -43,7 +45,7 @@ impl Restore {
     async fn run_async(&self, config: &ClientConfig) -> Result<(), ObnamError> {
         let temp = NamedTempFile::new()?;
 
-        let client = AsyncBackupClient::new(config)?;
+        let client = BackupClient::new(config)?;
 
         let genlist = client.list_generations().await?;
         let gen_id = genlist.resolve(&self.gen_id)?;
@@ -53,26 +55,16 @@ impl Restore {
         info!("restoring {} files", gen.file_count()?);
         let progress = create_progress_bar(gen.file_count()?, true);
         for file in gen.files()?.iter()? {
-            let file = file?;
-            match file.reason() {
+            let (fileno, entry, reason, _) = file?;
+            match reason {
                 Reason::FileError => (),
-                _ => {
-                    restore_generation(
-                        &client,
-                        &gen,
-                        file.fileno(),
-                        file.entry(),
-                        &self.to,
-                        &progress,
-                    )
-                    .await?
-                }
+                _ => restore_generation(&client, &gen, fileno, &entry, &self.to, &progress).await?,
             }
         }
         for file in gen.files()?.iter()? {
-            let file = file?;
-            if file.entry().is_dir() {
-                restore_directory_metadata(file.entry(), &self.to)?;
+            let (_, entry, _, _) = file?;
+            if entry.is_dir() {
+                restore_directory_metadata(&entry, &self.to)?;
             }
         }
         progress.finish();
@@ -84,6 +76,10 @@ impl Restore {
 /// Possible errors from restoring.
 #[derive(Debug, thiserror::Error)]
 pub enum RestoreError {
+    /// An error using a Database.
+    #[error(transparent)]
+    Database(#[from] DatabaseError),
+
     /// Failed to create a name pipe.
     #[error("Could not create named pipe (FIFO) {0}")]
     NamedPipeCreationError(PathBuf),
@@ -130,9 +126,9 @@ pub enum RestoreError {
 }
 
 async fn restore_generation(
-    client: &AsyncBackupClient,
+    client: &BackupClient,
     gen: &LocalGeneration,
-    fileid: i64,
+    fileid: FileId,
     entry: &FilesystemEntry,
     to: &Path,
     progress: &ProgressBar,
@@ -182,10 +178,10 @@ fn restored_path(entry: &FilesystemEntry, to: &Path) -> Result<PathBuf, RestoreE
 }
 
 async fn restore_regular(
-    client: &AsyncBackupClient,
+    client: &BackupClient,
     gen: &LocalGeneration,
     path: &Path,
-    fileid: i64,
+    fileid: FileId,
     entry: &FilesystemEntry,
 ) -> Result<(), RestoreError> {
     debug!("restoring regular {}", path.display());
@@ -293,9 +289,9 @@ fn path_to_cstring(path: &Path) -> CString {
     CString::new(path).unwrap()
 }
 
-fn create_progress_bar(file_count: i64, verbose: bool) -> ProgressBar {
+fn create_progress_bar(file_count: FileId, verbose: bool) -> ProgressBar {
     let progress = if verbose {
-        ProgressBar::new(file_count as u64)
+        ProgressBar::new(file_count)
     } else {
         ProgressBar::hidden()
     };
