@@ -1,6 +1,6 @@
 //! The `show-generation` subcommand.
 
-use crate::client::AsyncBackupClient;
+use crate::client::BackupClient;
 use crate::config::ClientConfig;
 use crate::error::ObnamError;
 use crate::fsentry::FilesystemKind;
@@ -26,7 +26,7 @@ impl ShowGeneration {
 
     async fn run_async(&self, config: &ClientConfig) -> Result<(), ObnamError> {
         let temp = NamedTempFile::new()?;
-        let client = AsyncBackupClient::new(config)?;
+        let client = BackupClient::new(config)?;
 
         let genlist = client.list_generations().await?;
         let gen_id = genlist.resolve(&self.gen_id)?;
@@ -35,8 +35,7 @@ impl ShowGeneration {
         let mut files = files.iter()?;
 
         let total_bytes = files.try_fold(0, |acc, file| {
-            file.map(|file| {
-                let e = file.entry();
+            file.map(|(_, e, _, _)| {
                 if e.kind() == FilesystemKind::Regular {
                     acc + e.len()
                 } else {
