@@ -5,6 +5,7 @@ use crate::cipher::CipherError;
 use crate::client::ClientError;
 use crate::cmd::restore::RestoreError;
 use crate::config::ClientConfigError;
+use crate::db::DatabaseError;
 use crate::generation::{LocalGenerationError, NascentError};
 use crate::genlist::GenerationListError;
 use crate::passwords::PasswordError;
@@ -51,6 +52,10 @@ pub enum ObnamError {
     #[error(transparent)]
     LocalGenerationError(#[from] LocalGenerationError),
 
+    /// Error using a Database.
+    #[error(transparent)]
+    Database(#[from] DatabaseError),
+
     /// Error restoring a backup.
     #[error(transparent)]
     RestoreError(#[from] RestoreError),
