@@ -8,7 +8,6 @@
 pub mod backup_progress;
 pub mod backup_reason;
 pub mod backup_run;
-pub mod benchmark;
 pub mod checksummer;
 pub mod chunk;
 pub mod chunker;
@@ -18,6 +17,8 @@ pub mod cipher;
 pub mod client;
 pub mod cmd;
 pub mod config;
+pub mod db;
+pub mod dbgen;
 pub mod engine;
 pub mod error;
 pub mod fsentry;
